clear all
cd "`c(pwd)'/"

********************
import excel "Data_Main.xls", sheet("Data_Main") firstrow
xtset ifscode year

** Inv / GDP
gen TInv = rinv / rgdpna * 100
gen PInv = priv_rinv / rgdpna * 100
gen GInv = publ_rinv / rgdpna * 100
** Capital Growth
gen grTK = (ln(rkna)-ln(L.rkna))*100 
gen grPK = (ln(kpriv)-ln(L.kpriv))*100 
gen grGK = (ln(kpubl)-ln(L.kpubl))*100
gen grGDP = (ln(rgdpna)-ln(L.rgdpna))*100

gen check = grGDP + grTK + grPK + grGK + TInv + PInv + GInv
foreach vv of varlist grTK grPK grGK TInv PInv GInv {
	replace `vv' = . if missing(check)
	}
collapse TInv PInv GInv grTK grPK grGK, by(countrygroup year)
reshape wide TInv PInv GInv grTK grPK grGK, i(year) j(countrygroup)
foreach vv in TInv PInv GInv grTK grPK grGK {
	label var `vv'1 "Adv"
	label var `vv'2 "Eme"
	label var `vv'3 "LIDCs"
	}

twoway (tsline TInv1, lwidth(thick) lcolor(navy)) ///
	(tsline TInv2, lwidth(thick) lcolor(orange_red) ) ///
	(tsline TInv3, lwidth(thick) lcolor(dkgreen)), ///
	title("Total", size(large)) name(TInv, replace) ///
	legend(off) ylabel(, labsize(medium)) xlabel(1960(10)2015, labsize(medium)) xtitle("") graphregion(color(white)) ///
	xsize(4) ysize(4) nodraw	
twoway (tsline PInv1, lwidth(thick) lcolor(navy)) ///
	(tsline PInv2, lwidth(thick) lcolor(orange_red) ) ///
	(tsline PInv3, lwidth(thick) lcolor(dkgreen)), ///
	title("Private", size(large)) name(PInv, replace) ///
	legend(off) ylabel(, labsize(medlarge)) xlabel(1960(10)2015, labsize(medium)) xtitle("") graphregion(color(white)) ///
	xsize(4) ysize(4) nodraw	
twoway (tsline GInv1, lwidth(thick) lcolor(navy)) ///
	(tsline GInv2, lwidth(thick) lcolor(orange_red) ) ///
	(tsline GInv3, lwidth(thick) lcolor(dkgreen)), ///
	title("Public", size(large)) name(GInv, replace) ///
	legend(off) ylabel(, labsize(medium)) xlabel(1960(10)2015, labsize(medium)) xtitle("") graphregion(color(white)) ///
	xsize(4) ysize(4) nodraw	
graph combine TInv PInv GInv, col(3) imargin(small) graphregion(color(white)) title("Average Investment (% of GDP)", size(medlarge)) name(Inv, replace) nodraw

twoway (tsline grTK1, lwidth(thick) lcolor(navy)) ///
	(tsline grTK2, lwidth(thick) lcolor(orange_red) ) ///
	(tsline grTK3, lwidth(thick) lcolor(dkgreen)), ///
	title("Total", size(large)) name(TInv, replace) ///
	legend(off) ylabel(, labsize(medium)) xlabel(1960(10)2015, labsize(medium)) xtitle("") graphregion(color(white)) ///
	xsize(4) ysize(4) nodraw	
twoway (tsline grPK1, lwidth(thick) lcolor(navy)) ///
	(tsline grPK2, lwidth(thick) lcolor(orange_red) ) ///
	(tsline grPK3, lwidth(thick) lcolor(dkgreen)), ///
	title("Private", size(large)) name(PInv, replace) ///
	legend(off) ylabel(, labsize(medlarge)) xlabel(1960(10)2015, labsize(medium)) xtitle("") graphregion(color(white)) ///
	xsize(4) ysize(4) nodraw	
twoway (tsline grGK1, lwidth(thick) lcolor(navy)) ///
	(tsline grGK2, lwidth(thick) lcolor(orange_red) ) ///
	(tsline grGK3, lwidth(thick) lcolor(dkgreen)), ///
	title("Public", size(large)) name(GInv, replace) ///
	legend(order(1 2 3) symxsize(8) cols(1) size(medsmall) pos(1) ring(0)) ylabel(, labsize(medium)) xlabel(1960(10)2015, labsize(medium)) xtitle("") graphregion(color(white)) ///
	xsize(4) ysize(4) nodraw	
graph combine TInv PInv GInv, col(3) imargin(small) graphregion(color(white)) title("Average Capital Growth (%)", size(medlarge)) name(grK, replace) nodraw

graph combine Inv grK, col(1) imargin(small) graphregion(color(white))
*graph export "tsplot.png", as(png) replace
