clear all
cd "`c(pwd)'/"

****************************************
**  Table 1. Summary Statistics
****************************************
import excel "Data_Main.xls", sheet("Data_Main") firstrow
drop if year<1960

** Inv / GDP
gen TInv = rinv / rgdpna * 100
gen PInv = priv_rinv / rgdpna * 100
gen GInv = publ_rinv / rgdpna * 100

** K / GDP 
gen TK = rkna / rgdpna * 100
gen PK = kpriv / rgdpna * 100
gen GK = kpubl / rgdpna * 100

foreach vv of varlist TInv PInv GInv TK PK GK {
	local vlist1 `vlist1' STAT_`vv'_Ave STAT_`vv'_STD
	local vlist2 `vlist2' STAT_`vv'
	egen STAT_`vv'_Ave_CG0 = mean(`vv')
	egen STAT_`vv'_STD_CG0 = sd(`vv')
	foreach cg in 1 2 3{
		egen STAT_`vv'_Ave_CG`cg' = mean(`vv') if countrygroup==`cg'
		egen STAT_`vv'_STD_CG`cg' = sd(`vv') if countrygroup==`cg'
		}
	}
collapse STAT*	
gen temp = 1
reshape long `vlist1', i(temp) j(countrygroup) string
reshape long `vlist2', i(temp countrygroup) j(stat) string
foreach vv of varlist _all {
	cap: replace `vv' = round(`vv',0.1)
	}
drop temp
export excel using "Results.xls", sheet("T1") sheetmodify firstrow(variables)

****************************************
**  Table 2. Correlation of Growth Rates
****************************************
import excel "Data_Main.xls", sheet("Data_Main") firstrow clear
xtset ifscode year

** Growth
gen grGDP = (ln(rgdpna)-ln(L.rgdpna))*100
gen grTK = (ln(rkna)-ln(L.rkna))*100 
gen grPK = (ln(kpriv)-ln(L.kpriv))*100 
gen grGK = (ln(kpubl)-ln(L.kpubl))*100
drop if year<1960

gen check = grGDP + grTK + grPK + grGK
foreach vv of varlist grGDP grTK grPK grGK {
	replace `vv' = . if missing(check)
	}

matrix accum R0 = grGDP grTK grPK grGK, nocons dev	
matrix R0 = corr(R0)	
matrix accum R1 = grGDP grTK grPK grGK if countrygroup==1, nocons dev	
matrix R1 = corr(R1)	
matrix accum R2 = grGDP grTK grPK grGK if countrygroup==2, nocons dev	
matrix R2 = corr(R2)	
matrix accum R3 = grGDP grTK grPK grGK if countrygroup==3, nocons dev	
matrix R3 = corr(R3)	
matrix RR = R0, R1 \ R2, R3
putexcel set "Results.xls", sheet("T2") modify
putexcel A1=matrix(RR)

