clear all
cd "`c(pwd)'/"

************************************************************
**  Data_T3_T4 Baseline
************************************************************
import excel "Data_Main.xls", sheet("Data_Main") firstrow clear
drop if year < 1961
gen period = trunc((year-1961)/3)
collapse (last) year country isocode countrygroup (mean) rgdpna kpriv kpubl emp, by(ifscode period)
xtset ifscode period
gen gryy = ln(rgdpna) - ln(l.rgdpna)
rename (kpriv kpubl emp) (kp kg ll)
gen lkp = l.kp
gen lkg = l.kg
gen lll = l.ll
save temp.dta, replace

use temp.dta, clear
keep gryy ll kp kg lll lkp lkg
order gryy ll kp kg lll lkp lkg	
drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
export excel using "Data_T3_T4.xls", sheet("0", replace) firstrow(variables)

foreach cg of numlist 1 2 3{
	use temp.dta, clear
	keep if countrygroup == `cg'
	keep gryy ll kp kg lll lkp lkg
	order gryy ll kp kg lll lkp lkg	
	drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
	export excel using "Data_T3_T4.xls", sheet("`cg'", replace) firstrow(variables)
	}
		
************************************************************
**  Data_T5_T6_2Y Alternative Data Frequencies 
**  Non-rolling 2-year average
************************************************************
import excel "Data_Main.xls", sheet("Data_Main") firstrow clear
drop if year < 1962
gen period = trunc((year-1960)/2)
collapse (last) year country isocode countrygroup (mean) rgdpna kpriv kpubl emp, by(ifscode period)
xtset ifscode period
gen gryy = ln(rgdpna) - ln(l.rgdpna)
rename (kpriv kpubl emp) (kp kg ll)
gen lkp = l.kp
gen lkg = l.kg
gen lll = l.ll
save temp.dta, replace

use temp.dta, clear
keep gryy ll kp kg lll lkp lkg
order gryy ll kp kg lll lkp lkg	
drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
sum gryy, d
drop if gryy > r(p99)
export excel using "Data_T5_T6_2Y.xls", sheet("0", replace) firstrow(variables)

foreach cg of numlist 1 2 3{
	use temp.dta, clear
	keep if countrygroup == `cg'
	keep gryy ll kp kg lll lkp lkg
	order gryy ll kp kg lll lkp lkg	
	drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
	sum gryy, d
	drop if gryy > r(p99)
	export excel using "Data_T5_T6_2Y.xls", sheet("`cg'", replace) firstrow(variables)
	}	

************************************************************
**  Data_T5_T6_2Y Alternative Data Frequencies 
**  Non-rolling 5-year average
************************************************************	
import excel "Data_Main.xls", sheet("Data_Main") firstrow clear
drop if year < 1959
gen period = trunc((year-1959)/5)
collapse (last) year country isocode countrygroup (mean) rgdpna kpriv kpubl emp, by(ifscode period)
xtset ifscode period
gen gryy = ln(rgdpna) - ln(l.rgdpna)
rename (kpriv kpubl emp) (kp kg ll)
gen lkp = l.kp
gen lkg = l.kg
gen lll = l.ll
save temp.dta, replace

use temp.dta, clear
keep gryy ll kp kg lll lkp lkg
order gryy ll kp kg lll lkp lkg	
drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
export excel using "Data_T5_T6_5Y.xls", sheet("0", replace) firstrow(variables)

foreach cg of numlist 1 2 3{
	use temp.dta, clear
	keep if countrygroup == `cg'
	keep gryy ll kp kg lll lkp lkg
	order gryy ll kp kg lll lkp lkg	
	drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
	export excel using "Data_T5_T6_5Y.xls", sheet("`cg'", replace) firstrow(variables)
	}		
	
************************************************************
**  Data_T7_T8 Time Fixed Effects Pre- and Post-1990
************************************************************
import excel "Data_Main.xls", sheet("Data_Main") firstrow clear
drop if year < 1961
gen period = trunc((year-1961)/3)
collapse (last) year country isocode countrygroup (mean) rgdpna kpriv kpubl emp, by(ifscode period)
xtset ifscode period
gen gryy = ln(rgdpna) - ln(l.rgdpna)
rename (kpriv kpubl emp) (kp kg ll)
gen lkp = l.kp
gen lkg = l.kg
gen lll = l.ll
save temp.dta, replace

use temp.dta, clear
gen tdummy = 0 if period <=9
replace tdummy = 1 if period >9
keep gryy ll kp kg lll lkp lkg tdummy
order gryy ll kp kg lll lkp lkg	tdummy
drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
export excel using "Data_T7_T8_HalfTFE.xls", sheet("0", replace) firstrow(variables)

foreach cg of numlist 1 2 3{
	use temp.dta, clear
	keep if countrygroup == `cg'
	gen tdummy = 0 if period <=9
	replace tdummy = 1 if period >9
	keep gryy ll kp kg lll lkp lkg tdummy
	order gryy ll kp kg lll lkp lkg	tdummy
	drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
	export excel using "Data_T7_T8_HalfTFE.xls", sheet("`cg'", replace) firstrow(variables)
	}	
	
************************************************************
**  Data_T7_T8 Time Fixed Effects 12-year TFE
************************************************************
import excel "Data_Main.xls", sheet("Data_Main") firstrow clear
drop if year < 1961
gen period = trunc((year-1961)/3)
collapse (last) year country isocode countrygroup (mean) rgdpna kpriv kpubl emp, by(ifscode period)
xtset ifscode period
gen gryy = ln(rgdpna) - ln(l.rgdpna)
rename (kpriv kpubl emp) (kp kg ll)
gen lkp = l.kp
gen lkg = l.kg
gen lll = l.ll
save temp.dta, replace

use temp.dta, clear
gen temp_period = trunc((period-2)/4)
tab temp_period, gen(tdummy)
keep gryy ll kp kg lll lkp lkg tdummy2 tdummy3 tdummy4
order gryy ll kp kg lll lkp lkg	tdummy2 tdummy3 tdummy4
drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
export excel using "Data_T7_T8_12TFE.xls", sheet("0", replace) firstrow(variables)

foreach cg of numlist 1 2 3{
	use temp.dta, clear
	keep if countrygroup == `cg'
	gen temp_period = trunc((period-2)/4)
	tab temp_period, gen(tdummy)
	keep gryy ll kp kg lll lkp lkg tdummy2 tdummy3 tdummy4
	order gryy ll kp kg lll lkp lkg	tdummy2 tdummy3 tdummy4
	drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
	export excel using "Data_T7_T8_12TFE.xls", sheet("`cg'", replace) firstrow(variables)
	}		

************************************************************
**  Data_T9_T10 Control for Human Capital
************************************************************
import excel "Data_Main.xls", sheet("Data_Main") firstrow clear
drop if year < 1961
gen period = trunc((year-1961)/3)
gen emphc = emp*hc
collapse (last) year country isocode countrygroup (mean) rgdpna kpriv kpubl emphc, by(ifscode period)
xtset ifscode period
gen gryy = ln(rgdpna) - ln(l.rgdpna)
rename (kpriv kpubl emp) (kp kg ll)
gen lkp = l.kp
gen lkg = l.kg
gen lll = l.ll
save temp.dta, replace

use temp.dta, clear
keep gryy ll kp kg lll lkp lkg
order gryy ll kp kg lll lkp lkg	
drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
export excel using "Data_T9_T10.xls", sheet("0", replace) firstrow(variables)

foreach cg of numlist 1 2 3{
	use temp.dta, clear
	keep if countrygroup == `cg'
	keep gryy ll kp kg lll lkp lkg
	order gryy ll kp kg lll lkp lkg	
	drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
	export excel using "Data_T9_T10.xls", sheet("`cg'", replace) firstrow(variables)
	}	

************************************************************
**  Data_T11_T12 Bootstrapping
************************************************************
import excel "Data_Main.xls", sheet("Data_Main") firstrow clear
drop if year < 1961
gen period = trunc((year-1961)/3)
collapse (last) year country isocode countrygroup (mean) rgdpna kpriv kpubl emp, by(ifscode period)
xtset ifscode period
gen gryy = ln(rgdpna) - ln(l.rgdpna)
rename (kpriv kpubl emp) (kp kg ll)
gen lkp = l.kp
gen lkg = l.kg
gen lll = l.ll
save temp.dta, replace

use temp.dta, clear
keep gryy ll kp kg lll lkp lkg ifscode
order gryy ll kp kg lll lkp lkg	ifscode
drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
export excel using "Data_T11_T12.xls", sheet("0", replace) firstrow(variables)

foreach cg of numlist 1 2 3{
	use temp.dta, clear
	keep if countrygroup == `cg'
	keep gryy ll kp kg lll lkp lkg ifscode
	order gryy ll kp kg lll lkp lkg	ifscode
	drop if missing(lkp) | missing(kp) | missing(lll) | missing(ll)
	export excel using "Data_T11_T12.xls", sheet("`cg'", replace) firstrow(variables)
	}

erase temp.dta	
